<?xml version="1.0" encoding="UTF-8" ?>
<xsl:stylesheet version="2.0" xmlns:marc="http://www.loc.gov/MARC21/slim"
    xmlns:xsl="http://www.w3.org/1999/XSL/Transform" exclude-result-prefixes="marc">
    <xsl:import href="MARC21slimUtils.xsl"/>
    <xsl:output method="xml" encoding="UTF-8" indent="yes"/>
  <xsl:param name="sourcefile" />
    <xsl:template match="/ead">
        <marc:collection xmlns:marc="http://www.loc.gov/MARC21/slim"
            xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
            xsi:schemaLocation="http://www.loc.gov/MARC21/slim http://www.loc.gov/standards/marcxml/schema/MARC21slim.xsd">
            <xsl:variable name="bulkdate" select="//unitdate[@encodinganalog='245$g']"/>

            <marc:record>
                <marc:leader>
                    <xsl:text>01125nam a2200289 a 4500</xsl:text>
                </marc:leader>
              <marc:controlfield tag="001">
                <xsl:value-of select="$sourcefile"/>
              </marc:controlfield>
                <marc:controlfield tag="008">
                    <xsl:text>071105s</xsl:text>
                    <xsl:value-of select="eadheader/filedesc/publicationstmt/date"/>
                    <xsl:text>\\\\ncu\\n\\s\\\\\\\\\\\eng\d</xsl:text>
                </marc:controlfield>

                <marc:datafield tag="040" ind1="" ind2="">
                    <marc:subfield code="a">NcRS</marc:subfield>
                    <marc:subfield code="c">NcRS</marc:subfield>
                    <marc:subfield code="e">dacs</marc:subfield>
                </marc:datafield>

                <xsl:if test="//unitid">
                    <marc:datafield tag="090" ind1="" ind2="">
                        <marc:subfield code="a">
                            <xsl:value-of select="normalize-space(//unitid/.)"/>
                        </marc:subfield>
                    </marc:datafield>
                </xsl:if>

                <xsl:if test="archdesc/did/origination/persname">
                    <marc:datafield tag="100" ind1="1" ind2="">
                        <marc:subfield code="a">
                            <xsl:value-of
                                select="normalize-space(archdesc/did/origination/persname/.)"/>
                        </marc:subfield>
                    </marc:datafield>
                </xsl:if>

                <xsl:if test="archdesc/did/origination/corpname">
                    <marc:datafield tag="110" ind1="2" ind2="">
                        <marc:subfield code="a">
                            <xsl:value-of
                                select="normalize-space(archdesc/did/origination/corpname/.)"/>
                        </marc:subfield>
                    </marc:datafield>
                </xsl:if>

                <xsl:if test="//unittitle">
                    <marc:datafield tag="245" ind1="1" ind2="0">
                        <marc:subfield code="a">
                            <xsl:value-of select="normalize-space(//unittitle/text())"/>
                        </marc:subfield>
                        <xsl:if test="//unitdate">
                            <marc:subfield code="f">
                                <xsl:value-of select="normalize-space(//unitdate/.)"/>.</marc:subfield>
                            <marc:subfield code="h">
                                <xsl:text>[manuscript]</xsl:text>
                            </marc:subfield>
                        </xsl:if>
                    </marc:datafield>
                </xsl:if>

                <xsl:if test="archdesc/did/physdesc">
                    <marc:datafield tag="300" ind1="" ind2="">
                        <xsl:for-each select="archdesc/did/physdesc/extent">
                            <marc:subfield code="a">
                                <xsl:value-of
                                    select="normalize-space(archdesc/did/physdesc/extent/.)"/>
                              <xsl:attribute name="code">
                                <xsl:value-of select="substring(@encodinganalog,5,1)"/>
                              </xsl:attribute>
                                <xsl:value-of select="normalize-space(.)"/>
                            </marc:subfield>
                        </xsl:for-each>
                    </marc:datafield>
                </xsl:if>

                <xsl:if test="archdesc/arrangement">
                    <marc:datafield tag="351" ind1="" ind2="">
                        <marc:subfield code="a">
                            <xsl:value-of select="normalize-space(archdesc/arrangement/p/.)"/>
                        </marc:subfield>
                    </marc:datafield>
                </xsl:if>

                <xsl:for-each select="archdesc/did/abstract">
                    <xsl:if test="@encodinganalog='520'">
                        <marc:datafield tag="520" ind1="" ind2="">
                            <marc:subfield code="a">
                                <xsl:value-of select="normalize-space(.)"/>
                            </marc:subfield>
                        </marc:datafield>
                    </xsl:if>

                    <xsl:if test="@encodinganalog='545'">
                        <marc:datafield tag="545" ind1="" ind2="">
                            <marc:subfield code="a">
                                <xsl:value-of select="normalize-space(.)"/>
                            </marc:subfield>
                        </marc:datafield>
                    </xsl:if>
                </xsl:for-each>

                <xsl:if test="archdesc/did/langmaterial">
                    <marc:datafield tag="546" ind1="" ind2="">
                        <marc:subfield code="a">
                            <xsl:value-of select="normalize-space(archdesc/did/langmaterial/.)"/>
                        </marc:subfield>
                    </marc:datafield>
                </xsl:if>

                <xsl:if test="archdesc/descgrp/accessrestrict">
                    <xsl:if test="archdesc/descgrp/accessrestrict/@encodinganalog='506'">
                        <marc:datafield tag="506" ind1="" ind2="">
                            <marc:subfield code="a">
                                <xsl:value-of
                                    select="normalize-space(archdesc/descgrp/accessrestrict/p/.)"/>
                            </marc:subfield>
                        </marc:datafield>
                    </xsl:if>
                </xsl:if>

                <xsl:if test="archdesc/descgrp/acqinfo">
                    <xsl:if test="archdesc/descgrp/acqinfo/@encodinganalog='541'">
                        <marc:datafield tag="541" ind1="" ind2="">
                            <marc:subfield code="a">
                                <xsl:value-of select="normalize-space(archdesc/descgrp/acqinfo/p/.)"
                                />
                            </marc:subfield>
                        </marc:datafield>
                    </xsl:if>
                </xsl:if>

                <xsl:if test="archdesc/descgrp/userestrict">
                    <xsl:if test="archdesc/descgrp/userestrict/@encodinganalog='540'">
                        <marc:datafield tag="540" ind1="" ind2="">
                            <marc:subfield code="a">
                                <xsl:value-of
                                    select="normalize-space(archdesc/descgrp/userestrict/.)"/>
                            </marc:subfield>
                        </marc:datafield>
                    </xsl:if>
                </xsl:if>

                <xsl:if test="archdesc/descgrp/prefercite">
                    <marc:datafield tag="524" ind1="" ind2="">
                        <marc:subfield code="a">
                            <xsl:value-of select="normalize-space(archdesc/descgrp/prefercite/p/.)"
                            />
                        </marc:subfield>
                    </marc:datafield>
                </xsl:if>

                <xsl:if test="archdesc/custodhist">
                    <marc:datafield tag="561" ind1="" ind2="">
                        <marc:subfield code="a">
                            <xsl:value-of select="normalize-space(archdesc/custodhist/.)"/>
                        </marc:subfield>
                    </marc:datafield>
                </xsl:if>

                <xsl:for-each select="//controlaccess/persname | //controlaccess/corpname">
                    <xsl:sort select="@encodinganalog"/>
                    <xsl:choose>
                        <xsl:when test="@encodinganalog='600'">
                            <marc:datafield tag="600" ind1="1" ind2="0">
                                <marc:subfield code="a">
                                    <xsl:value-of select="normalize-space(.)"/>
                                </marc:subfield>
                            </marc:datafield>
                        </xsl:when>

                        <xsl:when test="@encodinganalog='610'">
                            <marc:datafield tag="610" ind1="2" ind2="0">
                                <marc:subfield code="a">
                                    <xsl:value-of select="normalize-space(.)"/>
                                </marc:subfield>
                            </marc:datafield>
                        </xsl:when>

                        <xsl:when test="@encodinganalog='611'">
                            <marc:datafield tag="611" ind1="2" ind2="0">
                                <marc:subfield code="a">
                                    <xsl:value-of select="normalize-space(.)"/>
                                </marc:subfield>
                            </marc:datafield>
                        </xsl:when>

                        <xsl:when test="@encodinganalog='700'">
                            <marc:datafield tag="700" ind1="1" ind2="">
                                <marc:subfield code="a">
                                    <xsl:value-of select="normalize-space(.)"/>
                                </marc:subfield>
                            </marc:datafield>
                        </xsl:when>

                        <xsl:otherwise/>
                    </xsl:choose>
                </xsl:for-each>

                <xsl:for-each select="//controlaccess/genreform">
                    <xsl:if test="//@encodinganalog='655'">
                        <marc:datafield tag="655" ind1="" ind2="7">
                            <marc:subfield code="a">
                                <xsl:value-of select="normalize-space(.)"/>
                            </marc:subfield>
                            <marc:subfield code="2">
                                <xsl:value-of select="normalize-space(@source)"/>
                            </marc:subfield>
                        </marc:datafield>
                    </xsl:if>
                </xsl:for-each>

                <xsl:for-each
                    select="//controlaccess/subject[@source='lcsh'] | //controlaccess/geogname[@source='lcsh']">
                    <xsl:choose>
                        <xsl:when test="//@source='lcsh'">
                            <xsl:if test="//@encodinganalog='650'">
                                <marc:datafield tag="650" ind1="" ind2="0">
                                    <marc:subfield code="a">
                                        <xsl:value-of select="normalize-space(.)"/>
                                    </marc:subfield>
                                </marc:datafield>
                            </xsl:if>

                            <xsl:if test="//@encodinganalog='651'">
                                <marc:datafield tag="651" ind1="" ind2="0">
                                    <marc:subfield code="a">
                                        <xsl:value-of select="normalize-space(.)"/>
                                    </marc:subfield>
                                </marc:datafield>
                            </xsl:if>
                        </xsl:when>
                        <xsl:otherwise/>
                    </xsl:choose>
                </xsl:for-each>

                <xsl:if test="//repository">
                    <marc:datafield tag="710" ind1="2" ind2="">
                        <marc:subfield code="a">
                            <xsl:value-of
                                select="substring-before(normalize-space(//repository/corpname/text()),',')"
                            />.</marc:subfield>
                        <xsl:if test="//subarea">
                            <marc:subfield code="b">
                                <xsl:value-of select="normalize-space(//subarea/.)"
                            />.</marc:subfield>
                        </xsl:if>
                    </marc:datafield>
                </xsl:if>

                <xsl:for-each select="//controlaccess/title">
                    <xsl:choose>
                        <xsl:when test="//@rules='aacr2'">
                            <xsl:if test="//@encodinganalog='740'">
                                <marc:datafield tag="740" ind1="0" ind2="4">
                                    <marc:subfield code="a">
                                        <xsl:value-of select="normalize-space(.)"/>
                                    </marc:subfield>
                                </marc:datafield>
                            </xsl:if>
                        </xsl:when>
                        <xsl:otherwise/>
                    </xsl:choose>
                </xsl:for-each>

                <xsl:if test="eadheader/eadid">
                    <marc:datafield tag="856" ind1="4" ind2="1">
                        <marc:subfield code="y">View the finding aid online.</marc:subfield>
                        <marc:subfield code="u">
                            <xsl:value-of select="normalize-space(eadheader/eadid/@url)"/>
                        </marc:subfield>
                    </marc:datafield>
                </xsl:if>
            </marc:record>
        </marc:collection>
    </xsl:template>


    <xsl:template match="head"/>

    <xsl:template match="p">
        <xsl:value-of select="."/>
    </xsl:template>
</xsl:stylesheet>
